#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# peek_mails.py
#
# Zeigt ein paar Header-Daten von eingegangen eMails an.
#
# Als Workaround für diese blöde Umstellung auf "WebMailer Pro" bei
# HostEurope ... bzw. dessen Unfähigkeit, mit catch-all-Adressen
# umzugehen.
#
# 20.02.2021    D.Ahlgrimm

import email.header
import imaplib

# ----------------------------------------------------------------------
# liefert ein paar relevante Daten aus einer roh-eMail.
def parse_email(data):
    if len(data)!=2:
        return None
    data=data[0][1].decode()
    _from=_to=_subject=_date=""
    subj_open=False
    # via subj_open wird sowas hier umschifft:
    #    Subject: =?UTF-8?B?bm9jaCBlaW4gVMOkw6TDpMOkc3QuIGRpZXNtYWwgYWJlciBtaXQgZWlu?=
    #     =?UTF-8?Q?er_verdammt_langen_Betreffzeile=2c_die_nat=c3=bcrlich_auch_wieder?=
    #     =?UTF-8?Q?_ein_paar_verqu=c3=a4re_=c3=9cmlaute_enth=c3=a4lt_und_sowieso_gan?=
    #     =?UTF-8?Q?z_lang_und_Kacke_i=c3=9ft=2e=2e=2e=23=23=23---***_hexhex?=
    for ln in data.split("\n"):
        if ln.startswith(" ") and subj_open:
            try:
                t, e=email.header.decode_header(ln[1:])[0]
                _subject+=t.decode("utf8")
            except:
                pass
        else:
            subj_open=False

        if ln.startswith("From: "):
            _from=ln.split(" ", 1)[1].strip()
        elif ln.startswith("To: "):
            _to=ln.split(" ", 1)[1].strip()
        elif ln.startswith("Subject: "):
            subj_open=True
            _subject=ln.split(" ", 1)[1].strip()
            try:
                t, e=email.header.decode_header(_subject)[0]
                _subject=t.decode("utf8")
            except:
                pass
        elif ln.startswith("Date: "):
            _date=ln.split(" ", 1)[1].strip()
    return _from, _to, _subject, _date


# ----------------------------------------------------------------------
# 
if __name__=='__main__':
    mail=imaplib.IMAP4_SSL("blablafoobar.mail.server-he.de")
    mail.login("username", "password")

    fldrs=mail.list()
    if len(fldrs)==2 and fldrs[0]=="OK":
        for ln in fldrs[1]:
            fldr=ln.decode().split(' "." ')[1]
            mails=mail.select(fldr)
            if len(mails)==2 and mails[0]=="OK":
                try:
                    mail_cnt=int(mails[1][0].decode())
                except:
                    mail_cnt=0
                if fldr in ("HE-Reports"):
                    continue
                if mail_cnt>0:
                    print("%3d %s"%(mail_cnt, fldr))

                    result, data=mail.search(None, "ALL")
                    for mail_id in data[0].decode().split():
                        result, data=mail.fetch(mail_id, "(RFC822)")
                        ped=parse_email(data)
                        if ped is None:
                            print("???")
                        else:
                            _from, _to, _subject, _date=ped
                            print("\nFrom:   ", _from)
                            print("To:     ", _to)
                            print("Subject:", _subject)
                            print("Date:   ", _date)
                            #print(data[0][1].decode())
            else:
                print(">>>", fldr)
